@@ -1,5 +1,7 @@
 """
-Main interface for dynamodb service ServiceResource
+Type annotations for dynamodb service ServiceResource
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
 
 Usage::
 
@@ -63,7 +65,8 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.ServiceResourceTablesCollection)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetables)
     """
 
     def all(self) -> "ServiceResourceTablesCollection":
@@ -89,7 +92,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
     """
 
     attribute_definitions: List[Any]
@@ -117,12 +120,14 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch-writer)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete)
         """
 
     def delete_item(
@@ -174,12 +179,14 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> DeleteItemOutputTypeDef:
         """
-        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-item)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget-available-subresources)
         """
 
     def get_item(
@@ -210,12 +217,14 @@ class Table(Boto3ServiceResource):
         ExpressionAttributeNames: Dict[str, str] = None,
     ) -> GetItemOutputTypeDef:
         """
-        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget-item)
         """
 
     def load(self) -> None:
         """
-        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableload)
         """
 
     def put_item(
@@ -267,7 +276,8 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> PutItemOutputTypeDef:
         """
-        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput-item)
         """
 
     def query(
@@ -326,12 +336,14 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> QueryOutputTypeDef:
         """
-        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequery)
         """
 
     def reload(self) -> None:
         """
-        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereload)
         """
 
     def scan(
@@ -389,7 +401,8 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
     ) -> ScanOutputTypeDef:
         """
-        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescan)
         """
 
     def update(
@@ -403,7 +416,8 @@ class Table(Boto3ServiceResource):
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
     ) -> "_Table":
         """
-        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate)
         """
 
     def update_item(
@@ -457,17 +471,20 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> UpdateItemOutputTypeDef:
         """
-        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-item)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait-until-exists)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait-until-not-exists)
         """
 
 
@@ -476,14 +493,15 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetable)
         """
 
     def batch_get_item(
@@ -492,7 +510,8 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnConsumedCapacity: ReturnConsumedCapacity = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch-get-item)
         """
 
     def batch_write_item(
@@ -502,7 +521,8 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch-write-item)
         """
 
     def create_table(
@@ -519,10 +539,12 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         Tags: List["TagTypeDef"] = None,
     ) -> _Table:
         """
-        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate-table)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget-available-subresources)
         """
